@@ -333,6 +333,7 @@ xsh_mflat_combine_flats(cpl_frameset *raw_set, cpl_frameset *on_set,
       for (i = 0; i < nraws; i++) {
         sprintf(prefix, "FLAT_SUB_%d_", i);
         frm = cpl_frameset_get_frame(raw_set, i);
+        xsh_monitor_flux(frm, cen_order_tab_frame, instrument, XSH_QC_RAW_FLUX);
         //xsh_free_frame(&sub);
         sub = xsh_subtract_bias(frm, master_bias_frame, instrument, prefix,
             pre_overscan_corr, 1);
@@ -407,8 +408,9 @@ xsh_combine_flats_and_detect_edges( cpl_frameset *raw_set,
   check(*rmdark=xsh_mflat_combine_flats(raw_set,on_set,off_set,bpmap_frame,master_bias_frame,
       master_dark_frame,cen_order_tab_frame,instrument,stack_par,pre_overscan_corr));
 
+
   /* for QC monitor the lamp level after (bias) and dark subtraction */
-  check(xsh_monitor_flux(*rmdark,qc_cen_order_tab_frame, instrument));
+  check(xsh_monitor_flux(*rmdark,qc_cen_order_tab_frame, instrument, XSH_QC_FLUX));
 
   /* detect order edge */
   xsh_msg("Detect order edges");
@@ -835,11 +837,13 @@ static void xsh_mflat(cpl_parameterlist* parameters, cpl_frameset* frameset)
      /* END case VIS/NIR arm */
   } else {  
      /* BEGIN case UVB arm */
- 
+
      check( xsh_order_split_qth_d2( cen_order_tab_frame, spectralformat_frame, 
                                     &qth_cen_order_tab_frame, &d2_cen_order_tab_frame, instrument));
 
      check( xsh_instrument_update_lamp( instrument, XSH_LAMP_QTH));
+
+     //Here computes QC
      check( xsh_combine_flats_and_detect_edges( qth, on, off,bpmap, master_bias,
                                    master_dark, qth_cen_order_tab_frame,
                                    cen_order_tab_frame,stack_par, 
@@ -848,11 +852,11 @@ static void xsh_mflat(cpl_parameterlist* parameters, cpl_frameset* frameset)
                                   &qth_edges_order_tab_frame, 
                                    &qth_rmdark,
                                    instrument));
-
-
+     //Here QC already computed
 
      det_order->min_sn = d2_det_order->min_sn;
      check( xsh_instrument_update_lamp( instrument, XSH_LAMP_D2));
+
      check( xsh_combine_flats_and_detect_edges( d2, on, off,bpmap, master_bias,
                                    master_dark, d2_cen_order_tab_frame,
                                    cen_order_tab_frame,stack_par,
@@ -861,6 +865,7 @@ static void xsh_mflat(cpl_parameterlist* parameters, cpl_frameset* frameset)
                                   &d2_edges_order_tab_frame,
                                    &d2_rmdark,
                                    instrument));
+     //Here QC already computed
 
 
      check(edges_order_tab_frame=xsh_flat_merge_qth_d2_tabs(qth_edges_order_tab_frame,
