@@ -112,6 +112,10 @@ Input Frames : \n\
   - A table to set response sampling points (Tag = RESP_FIT_POINTS_CAT_arm)\n\
   - An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
     if provided this is the one used to flux calibrate the spectra\n\
+  - [OPTIONAL,physmod mode] A table listing sky line positions (Tag = SKY_LINE_LIST_arm)\n\
+    this is used to be able to control quality of sky subtraction, for example\n\
+    projecting guess positions on the product SCI_SLIT_STARE_SUB_SKY_arm\n\
+    and is required if sky-method=BSPLINE\n\
 Products : \n\
   - [If STD is in catal] The response ord-by-ord function (Tag = PREFIX_RESPONSE_ORDER1D_SLIT_arm)\n\
   - [If STD is in catal] The response merged function (Tag = PREFIX_RESPONSE_MERGE1D_SLIT_arm)\n\
@@ -663,7 +667,6 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
    * 2x2 std 1x1 mflat,mbias --> correct bin of mflat,mbias
    *
    */
-  check(xsh_frameset_uniform_bin(&raws, &calib,instrument));
 
 
   check(xsh_slit_stare_get_calibs(calib,instrument, &spectralformat_frame,
@@ -693,7 +696,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
      xsh_msg_error("Provide std star catalog frame");
      return CPL_ERROR_DATA_NOT_FOUND;
   }
-  //high_abs_win=xsh_find_frame_with_tag(calib,XSH_HIGH_ABS_WIN,instrument);
+
   tell_mod_cat=xsh_find_frame_with_tag(calib,XSH_TELL_MOD_CAT,instrument);
 
   /* to compute efficiency */
@@ -788,8 +791,13 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
 
   xsh_free_frame(&rmbkg);
   /* now we divide by the flat for proper sky subtraction */
+  cpl_frameset* extra=cpl_frameset_new();
+  cpl_frameset_insert(extra,cpl_frame_duplicate(clean_obj));
+  check(xsh_frameset_uniform_bin(&extra, &calib,instrument));
+  clean_obj=cpl_frameset_get_frame(extra,0);
   check( div_frame = xsh_check_divide_flat( do_flatfield, clean_obj,
     master_flat, instrument, prefix));
+  cpl_frameset_delete(extra);
   xsh_add_temporary_file(cpl_frame_get_filename(div_frame));
   xsh_free_frame(&sky_frame);
   xsh_free_frame(&sky_frame_eso);
@@ -1179,7 +1187,7 @@ cleanup:
   xsh_free_frame( &ext_frame_eso ) ;
   xsh_free_frame( &clean_frame) ;
   xsh_free_frame( &div_clean_frame) ;
-  xsh_free_frame( &clean_obj) ;
+  //xsh_free_frame( &clean_obj) ;
   xsh_free_frame( &res_1D_frame) ;
   xsh_free_frame( &res_2D_frame) ;
   xsh_free_frame(&res_2D_sky_frame) ;
