@@ -579,7 +579,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   int corr_sky=0;
   int cut_uvb_spectrum=0;
   int scale_nod=0;
-  int scale_stack=4;
+  //int scale_stack=4;
   cpl_frame* frm_rejected=NULL;
   /**************************************************************************/
   /* DFS management */
