@@ -1,4 +1,6 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
 #  import sys
   import numpy
@@ -80,13 +82,13 @@ try:
           bpm.readImage(fits_extension=2)
           img_bpm = ImageDisplay()
 
-	  img_obj.setLabels('Wavelength [nm]','Position Along Slit [arcsec]')
+          img_obj.setLabels('Wavelength [nm]','Position Along Slit [arcsec]')
           y_size, x_size = obj.image.shape
 
           img_obj.setXLinearWCSAxis(obj.crval1,obj.cdelt1,obj.crpix1)
           img_obj.setYLinearWCSAxis(obj.crval2,obj.cdelt2,obj.crpix2)
 
-	  #img_obj.setLimits((1,x_size),(0,y_size))
+          #img_obj.setLimits((1,x_size),(0,y_size))
           img_obj.display(subplot, title, self.paragraph(tooltip),obj.image,bpm.image)
 
     def oplotImageScatter(self,img,tab,ext,binx,biny,Xcol,Ycol,subplot, marker = 'o', size = 10, color = 'blue' ):
@@ -109,13 +111,13 @@ try:
           bpm.readImage(fits_extension=2)
           img_bpm = ImageDisplay()
 
-	  img_disp.setLabels(Xlab,Ylab)
+          img_disp.setLabels(Xlab,Ylab)
           y_size, x_size = obj.image.shape
 
           img_disp.setXLinearWCSAxis(obj.crval1,obj.cdelt1,obj.crpix1)
           img_disp.setYLinearWCSAxis(obj.crval2,obj.cdelt2,obj.crpix2)
 
-	  #self.img_obj.setLimits((0,x_size),(0,y_size))
+          #self.img_obj.setLimits((0,x_size),(0,y_size))
 
 
     #2D image display
@@ -300,11 +302,11 @@ try:
       arm=self.seq_arm
 
       if arm == "UVB":
- 	 self.arm_uvb_found = True
+         self.arm_uvb_found = True
       if arm == "VIS":
- 	 self.arm_vis_found = True
+         self.arm_vis_found = True
       if arm == "NIR":
- 	 self.arm_nir_found = True
+         self.arm_nir_found = True
 
 # For any arm search a list of input frames
       #print "arm=",arm , "prefix=",prefix 
@@ -343,7 +345,7 @@ try:
         self.edges_tab = PipelineProduct(hdulist)
         #self.nima += 1
         #print "found edges tab"
-	
+        
       key = prefix+"ON_"+arm
       if key in frames :
         self.frameON_found = True
@@ -486,7 +488,7 @@ try:
       #print "mfat check:",  self.edges_tab_found, self.mflat_found
       if (self.resid_tab_found == True and self.frameON_found == True) or (self.edges_tab_found == True and self.mflat_found == True): 
         #and self.lineguess_found == True 
-        title_pref = 'Linear-extracted and Merged Spectrum.'	      
+        title_pref = 'Linear-extracted and Merged Spectrum.'          
 
         tooltip_spectrum ="""\
         Plot of the linear-extracted and merged spectrum of the object 
@@ -496,16 +498,16 @@ try:
         """
 
 
-	if self.arm_uvb_found == True:
-      	  title_spectrum   = title_pref
+        if self.arm_uvb_found == True:
+          title_spectrum   = title_pref
 
-	if self.arm_vis_found == True:
-      	  title_spectrum   = title_pref
+        if self.arm_vis_found == True:
+          title_spectrum   = title_pref
 
-	if self.arm_nir_found == True:
-      	  title_spectrum   = title_pref
-	   
-	   
+        if self.arm_nir_found == True:
+          title_spectrum   = title_pref
+           
+           
         #Display ON frame
 
         #Overplot initial list of lines
@@ -681,12 +683,12 @@ try:
          self.par.setModelParameters(paramList,rec_id)
 
       elif rec_id[4:11] == "wavecal" :
-         print "found wavecal params"
+         print("found wavecal params")
 
       elif rec_id[4:12] == "flexcomp" :
-         print "found flexcomp params"
+         print("found flexcomp params")
       else :
-         print "recipe" ,rec_id,  "not supported"
+         print("recipe" ,rec_id,  "not supported")
 
       return paramList
 
@@ -702,6 +704,6 @@ This is an interactive window which help asses the quality of the execution of a
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
   raise
 
