@@ -1,4 +1,6 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
 #  import sys
   import numpy
@@ -82,7 +84,8 @@ try:
            #in case response is available we need to reduce fonts
            subplot.set_title(title, fontsize=7)
         try:
-            subplot.figure.tight_layout()
+            pass
+            #subplot.figure.tight_layout()
         except AttributeError:
             pass
 
@@ -118,7 +121,7 @@ try:
           bpm.readImage(fits_extension=2)
           img_bpm = ImageDisplay()
 
-	  img_obj.setLabels('Wavelength [nm]','Position Along Slit \n [arcsec]')
+          img_obj.setLabels('Wavelength [nm]','Position Along Slit \n [arcsec]')
           y_size, x_size = obj.image.shape
           #print 'x_size=',x_size , 'y_size=',y_size
           #print 'crval1=',obj.crval1,'crpix1=',obj.crpix1,'cdelt1=',obj.cdelt1 
@@ -126,7 +129,7 @@ try:
           img_obj.setXLinearWCSAxis(obj.crval1,obj.cdelt1,obj.crpix1)
           img_obj.setYLinearWCSAxis(obj.crval2,obj.cdelt2,obj.crpix2)
 
-	  #img_obj.setLimits((0,x_size),(0,y_size))
+          #img_obj.setLimits((0,x_size),(0,y_size))
           #print bpm.image
           bp_code_missing_data = 524288
           bp_code_sky_model_inaccurate = 8388608
@@ -191,8 +194,8 @@ try:
         self.RN1 = "1514-1548 nm"
         self.OPTI5_NAME = hdulist[0].header['ESO INS OPTI5 NAME']
         if "JH" in self.OPTI5_NAME :
-   	  self.arm_nir_jh_found = True
-          print "Found NIR JH filter"
+          self.arm_nir_jh_found = True
+          print("Found NIR JH filter")
         else :
           self.SN2 = hdulist[0].header['ESO QC FLUX2 SN']
           self.RN2 = "2214-2243 nm"
@@ -302,11 +305,11 @@ try:
       arm=self.seq_arm
 
       if arm == "UVB":
- 	 self.arm_uvb_found = True
+         self.arm_uvb_found = True
       if arm == "VIS":
- 	 self.arm_vis_found = True
+         self.arm_vis_found = True
       if arm == "NIR":
- 	 self.arm_nir_found = True
+         self.arm_nir_found = True
 
 
 # For any arm search a list of input frames
@@ -335,7 +338,7 @@ try:
         self.flux_qual1D = PipelineProduct(hdulist)
         self.nima += 1
         #print "found FLUX_MERGED1D spectrum"
-	
+        
       key = prefix+"MERGE2D_"+arm
       if key in frames :
         self.spectrum2D_found = True
@@ -523,7 +526,7 @@ try:
 
       else : 
         self.subtext_nodata    = figure.add_subplot(1,1,1)
-        print "found no spectrum data"
+        print("found no spectrum data")
 
 
           
@@ -537,7 +540,7 @@ try:
     def plotProductsGraphics(self):
       if self.spectrum1D_found == True and self.spectrum2D_found == True: 
         #and self.lineguess_found == True 
-        title_pref = 'Standard-extracted and Merged Spectrum.'	      
+        title_pref = 'Standard-extracted and Merged Spectrum.'        
         title_flux_spectrum = 'Standard Extracted, Merged, and Flux Calibrated Spectrum.'
         tooltip_spectrum ="""\
                           Plot of the standard-extracted and merged spectrum of the object (blue line) as total flux (ADU) versus wavelength (nm). The +-1 sigma uncertainties are plotted as the light blue region encompassing the object spectrum (and bounded by the light grey spectra). Flagged pixels are marked with a dark-grey vertical bar stretching between the +- 1 sigma limits. Flagged bad pixels that are decoded as "bad pixels" are marked by a red vertical bar stretching between the +- 1 sigma limits. Note that this spectrum is not flux calibrated."""
@@ -561,18 +564,18 @@ try:
                               spectrum from the catalog is overplotted for
                               comparison purposes as a green line."""
 
-	if self.arm_uvb_found == True:
-      	  title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2)
+        if self.arm_uvb_found == True:
+          title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2)
 
-	if self.arm_vis_found == True:
-      	  title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2,self.SN3,self.RN3)
+        if self.arm_vis_found == True:
+          title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2,self.SN3,self.RN3)
 
-	if self.arm_nir_found == True and self.arm_nir_found == True:
-      	     title_spectrum   = title_pref+' \n SN: %#.2f (%#s); '% (self.SN1,self.RN1)
+        if self.arm_nir_found == True and self.arm_nir_found == True:
+             title_spectrum   = title_pref+' \n SN: %#.2f (%#s); '% (self.SN1,self.RN1)
         elif self.arm_nir_found == True :
-      	     title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); '% (self.SN1,self.RN1,self.SN2,self.RN2)
-	   
-	   
+             title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); '% (self.SN1,self.RN1,self.SN2,self.RN2)
+           
+           
         #Spectrum plot
 
         self.plotSpectrum(self.spectrum1D,self.error1D,self.qual1D,self.decode_bp,self.subplot_spectrum,title_spectrum,tooltip_spectrum)
@@ -590,7 +593,7 @@ try:
 
 
         #Image
-      	info_bin_size = 'Pixel size: %#.3f [nm] x %#.3f [arcsec]'% (self.CDELT1,self.CDELT2)
+        info_bin_size = 'Pixel size: %#.3f [nm] x %#.3f [arcsec]'% (self.CDELT1,self.CDELT2)
 
         title_image_obj   = '2D Merged ' + self.obj_type +'Spectrum.'+ info_bin_size
         tooltip_image_obj ="""\
@@ -648,7 +651,7 @@ try:
                                  fontsize=18, ha='left', va='center', alpha=1.0)
         self.subtext_nodata.tooltip="""\
                                     Merged spectrum not found in the products"""
-        print "found no spectrum data"
+        print("found no spectrum data")
  
   
     # This function specifies which are the parameters that should be presented
@@ -659,7 +662,7 @@ try:
     # with the parameter list 
     # Note also that parameters have to be prefixed by the 'recipe name:'
 
-	
+        
     def setInteractiveParameters(self):
       paramList = list()
 
@@ -699,6 +702,6 @@ This is an interactive window which help asses the quality of the execution of a
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
   raise
 
