@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 from reflex import RecipeParameter
 class Parameters(RecipeParameter):
 
@@ -44,7 +46,7 @@ class Parameters(RecipeParameter):
     def setGeneralObjectParameters(self,paramList,rec_id):
 
       group="general"
-      print "rec_id=",rec_id
+      print("rec_id=",rec_id)
 
       self.setDecodeBpParameters(paramList,rec_id,group)
       self.setPreOverscanParameters(paramList,rec_id,group)
@@ -60,13 +62,13 @@ class Parameters(RecipeParameter):
 
 
       if "stare" in rec_id:
-        print "stare"
+        print("stare")
         help5=help5+"If sky-subtract is set to TRUE this must be set to TRUE."
         paramList.append(RecipeParameter(rec_id,displayName="compute-map",group=group,description=help5))
         paramList.append(RecipeParameter(rec_id,displayName="trace-obj",group=group,description=help6))
 
       if "nod" in rec_id :
-        print "extract method"
+        print("extract method")
         paramList.append(RecipeParameter(rec_id,displayName="extract-method",group=group,description=help7))
 
       if "slit_offset" in rec_id :
