@@ -654,7 +654,7 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
   int j=0;
   cpl_vector* loc_vec=NULL;
   double* pvec=NULL;
-  double* pvec_all_ord=NULL;
+  double* ptab_all_ord=NULL;
   double* py=NULL;
   double ymin=0;
   double ymax=0;
@@ -665,7 +665,7 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
   double yavg=0;
   char qc_line[40];
   cpl_propertylist* plist=NULL;
-  cpl_vector* vec_all_ord=NULL;
+  cpl_table* tab_all_ord=NULL;
   int ymin_all_ord=0;
   int ymax_all_ord=0;
 
@@ -679,9 +679,10 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
 
   check(nsel=cpl_table_and_selected_int(tab,"Slit_index",CPL_EQUAL_TO,4));
   check(ext=cpl_table_extract_selected(tab));
-
-  check(vec_all_ord=cpl_vector_new(ord_max-ord_min+1));
-  check(pvec_all_ord=cpl_vector_get_data(vec_all_ord));
+  tab_all_ord=cpl_table_new(ord_max-ord_min+1);
+  cpl_table_new_column(tab_all_ord,"data",CPL_TYPE_DOUBLE);
+  cpl_table_fill_column_window_double(tab_all_ord,"data",0,ord_max-ord_min+1,0);
+  check(ptab_all_ord=cpl_table_get_data_double(tab_all_ord,"data"));
 
   for(i=ord_min;i<=ord_max;i++) {
      check(nsel=cpl_table_and_selected_int(ext,"Order",CPL_EQUAL_TO,i));
@@ -716,7 +717,7 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
         check(ymax=cpl_vector_get_max(loc_vec));
         check(ymed=cpl_vector_get_median(loc_vec));
         check(yavg=cpl_vector_get_mean(loc_vec));
-        check(pvec_all_ord[i-ord_min]=yavg);
+        check(ptab_all_ord[i-ord_min]=yavg);
 
 
         //xsh_msg("ymin=%g ymax=%g ymed=%g yavg=%g",ymin,ymax,ymed,yavg);
@@ -740,17 +741,22 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
      } else {
         xsh_msg_warning("Too few values of 'Slit_index=4' for Order=%d",i);
         xsh_msg_warning("No %s (and similar) QC parameters can be generated for order %d",XSH_QC_LINE_DIFMIN,i);
+        check(cpl_table_set_invalid(tab_all_ord,"data",i-ord_min));
      }
      check(cpl_table_select_all(ext));
      xsh_free_table(&tbl);
   }
-  check(yavg=cpl_vector_get_mean(vec_all_ord));
-  check(ymax=cpl_vector_get_max(vec_all_ord));
-  check(ymed=cpl_vector_get_median(vec_all_ord));
-  check(ymin=cpl_vector_get_min(vec_all_ord));
-
+  cpl_table_erase_invalid(tab_all_ord);
 
 
+  check(yavg=cpl_table_get_column_mean(tab_all_ord,"data"));
+  check(ymax=cpl_table_get_column_max(tab_all_ord,"data"));
+  check(ymed=cpl_table_get_column_median(tab_all_ord,"data"));
+  check(ymin=cpl_table_get_column_min(tab_all_ord,"data"));
+  /*
+  xsh_msg("All: ymin_all=%g ymin_all_ord=%g ymax_all=%g ymax_all_ord=%g ymed=%g yavg=%g",
+		  ymin_all,ymin_all_ord, ymax_all,ymax_all_ord, ymed,yavg);
+		  */
   sprintf(qc_line,"%s",XSH_QC_LINE_DIFMIN);
   check(cpl_propertylist_append_double(plist,qc_line,ymin_all));
   check(cpl_propertylist_set_comment(plist,qc_line,XSH_QC_LINE_DIFMIN_C));
@@ -783,7 +789,7 @@ xsh_wavetab_qc(cpl_frame* frm_tab, const int is_poly)
   xsh_free_table(&ext);
   xsh_free_table(&tbl);
   xsh_free_vector(&loc_vec);
-  xsh_free_vector(&vec_all_ord);
+  xsh_free_table(&tab_all_ord);
   xsh_free_propertylist(&plist);
 
 
