@@ -997,7 +997,7 @@ xsh_detect_arclines_dan( cpl_frame *frame,
             vorderdata[i]!=vorderdata[i-1] ||
             i==sol_size-1) {
 
-          //special case for last line
+          //special case for last line: TODO AMO: Why this???
           if (i==sol_size-1) {
             i++;
           }
@@ -1051,7 +1051,8 @@ xsh_detect_arclines_dan( cpl_frame *frame,
           starti=i;
 	  nbflag=0;
         }
-	if (flag[i]!=0) {
+       
+	if (i<sol_size && flag[i]!=0) {
 	  nbflag+=1;
 	}
     }// endfor
