@@ -574,10 +574,16 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
     double nod_throw = xsh_pfits_get_nodthrow(plist);
     //xsh_msg("before slit min: %g max: %g",slit_ext_min,slit_ext_max);
     int nslit = xsh_rec_list_get_nslit(rec_list, 0);
-    int hslit = round(0.5 * nod_throw / slit_step);
+    int hslit =0;
+    if (nod_throw <= 5.5 ) {
+       hslit = round(0.5 * nod_throw / slit_step);
+    } else {
+       hslit = round(0.5 * (11.-nod_throw) / slit_step);
+    }
+    xsh_msg("nod_throw=%g slit_step=%g nslit=%d hslit=%d",nod_throw,slit_step,nslit,hslit);
     slit_ext_max = nslit/2 + hslit;
     slit_ext_min = nslit/2 - hslit;
-    //xsh_msg("after slit min: %g max: %g",slit_ext_min,slit_ext_max);
+    xsh_msg("after slit min: %g max: %g",slit_ext_min,slit_ext_max);
     xsh_free_propertylist(&plist);
   }
 
@@ -711,7 +717,7 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
 
         ylow = slit_ext_min;
         yup = slit_ext_max;
-
+        //xsh_msg("mask_hsize=%d",mask_hsize);
         if (mask_hsize <= 0) {
           if(i == 0 && ilambda==0) {
              xsh_msg("Object extraction limits: [%d,%d] [bin]/[%g,%g] [arcsec]",
