@@ -452,6 +452,12 @@ typedef struct {
       int fpn_nsamples;/** FPN number of samples */
 }xsh_fpn_param;
 
+typedef struct {
+      int pd_dc_x;/** FPN dc_x */
+      int pd_dc_y;/** FPN dc_y */
+      int pd_compute;/** FPN compute */
+}xsh_pd_noise_param;
+
 
 typedef struct {
       const char* ron_method;/** RON method */
@@ -584,8 +590,10 @@ xsh_parameters_ref2_create(const char* recipe_id,cpl_parameterlist* list,
 void 
 xsh_parameters_ron_create(const char* recipe_id,cpl_parameterlist* list, 
                           xsh_ron_param p);
-
 void 
+xsh_parameters_pd_noise_create(const char* recipe_id,
+  cpl_parameterlist* list, xsh_pd_noise_param p);
+void
 xsh_parameters_fpn_create(const char* recipe_id,cpl_parameterlist* list, 
                           xsh_fpn_param p);
 
