@@ -338,7 +338,7 @@
 #define XSH_SDP_COLUMN_WAVE_UNIT            "nm"
 #define XSH_SDP_COLUMN_WAVE_FORMAT          "1E"
 #define XSH_SDP_COLUMN_WAVE_TYPE            "spec:Data.SpectralAxis.Value"
-#define XSH_SDP_COLUMN_WAVE_UCD             "em.wl"
+#define XSH_SDP_COLUMN_WAVE_UCD             "em.wl;obs.atmos"
 #define XSH_SDP_COLUMN_FLUX                 "FLUX"
 #define XSH_SDP_COLUMN_FLUX_UNIT            XSH_SDP_ADU_UNIT
 #define XSH_SDP_COLUMN_FLUX_UNIT_CALIB      XSH_SDP_FLUX_UNIT
@@ -697,4 +697,6 @@ cpl_error_code
 xsh_pfits_combine_headers(cpl_propertylist* header,cpl_frameset* set);
 cpl_error_code
 xsh_pfits_combine_two_frames_headers(cpl_frame* first, cpl_frame* second);
+int xsh_pfits_is_obs(cpl_propertylist* plist);
+int xsh_pfits_is_flat(cpl_propertylist* plist);
 #endif
