@@ -82,6 +82,25 @@ int xsh_pfits_get_qc_ncrh( const cpl_propertylist * plist)
     return returnvalue ;
 }
 
+/**
+  @brief
+    Find out the QC NCRH value
+  @param plist
+    The property list to read from
+  @return
+    The requested value
+ */
+double xsh_pfits_get_qc_ncrh_mean( const cpl_propertylist * plist)
+{
+  double returnvalue = -1 ;
+
+  check_msg( xsh_get_property_value( plist, XSH_QC_CRH_NUMBER_MEAN,
+				     CPL_TYPE_DOUBLE, &returnvalue ),
+	     "Error reading Keyword '%s'", XSH_QC_CRH_NUMBER_MEAN ) ;
+  cleanup:
+    return returnvalue ;
+}
+
 
 
 /*--------------------------------------------------------------------------- */
@@ -743,7 +762,7 @@ cleanup:
 }
 
 /**
-  @brief    Write the QC.NCRH value
+  @brief    Write the QC.NCRH.AVG value
   @param    plist      Property list to write to
   @param    value      The value to write
  */
@@ -751,7 +770,7 @@ cleanup:
 void
 xsh_pfits_set_qc_ncrh_mean (cpl_propertylist * plist, const double value)
 {
-  check_msg (cpl_propertylist_update_float (plist, XSH_QC_CRH_NUMBER_MEAN, value),
+  check_msg (cpl_propertylist_update_double (plist, XSH_QC_CRH_NUMBER_MEAN, value),
 	     "Error writing keyword '%s'", XSH_QC_CRH_NUMBER_MEAN);
   cpl_propertylist_set_comment(plist, XSH_QC_CRH_NUMBER_MEAN,XSH_QC_CRH_NUMBER_MEAN_C);
 
@@ -759,6 +778,23 @@ cleanup:
   return;
 }
 
+/**
+  @brief    Write the QC.NCRH.TOT value
+  @param    plist      Property list to write to
+  @param    value      The value to write
+ */
+/*-------------------------------------------------------------------------- */
+void
+xsh_pfits_set_qc_ncrh_tot (cpl_propertylist * plist, const int value)
+{
+  check_msg (cpl_propertylist_update_int (plist, XSH_QC_CRH_NUMBER_TOT, value),
+	     "Error writing keyword '%s'", XSH_QC_CRH_NUMBER_TOT);
+  cpl_propertylist_set_comment(plist, XSH_QC_CRH_NUMBER_TOT,XSH_QC_CRH_NUMBER_TOT_C);
+
+cleanup:
+  return;
+}
+
 /**
   @brief    Write the QC.CRRATE value
   @param    plist      Property list to write to
