@@ -315,7 +315,7 @@ xsh_update_pheader_in_image_multi(cpl_frame *frame,
 
 cpl_error_code
 xsh_monitor_flux(cpl_frame* frm_ima,const cpl_frame* frm_tab,
-  xsh_instrument* instrument);
+  xsh_instrument* instrument, const char* qc_key_prefix);
 cpl_error_code 
 xsh_frameset_dump_nod_info(cpl_frameset* set);
 void
