@@ -88,6 +88,19 @@ xsh_scired_slit_nod_accurate(
                              const char* rec_prefix
    );
 
+
+cpl_error_code
+xsh_get_dispersion_calibs(cpl_frameset* calib, xsh_instrument* instrument,
+		const int do_computemap,
+		cpl_frame** model_config_frame, cpl_frame** wave_tab,
+		cpl_frame** wavemap);
+
+cpl_error_code
+xsh_get_normal_calibs(cpl_frameset* calib,xsh_instrument* instrument,
+		const char* recipe_id,int pscan,cpl_frame** spectral_format,
+		cpl_frame** master_bias,
+		cpl_frame** bpmap,cpl_frame** order_tab_edges,cpl_frame** master_flat);
+
 cpl_error_code
 xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
                                cpl_frameset* calib,
